package com.amazon.inputsdk.demo;

import android.view.KeyEvent;

import com.amazon.device.inputmapping.input.InputAction;
import com.amazon.device.inputmapping.input.InputControls;
import com.amazon.device.inputmapping.input.InputGroup;
import com.amazon.device.inputmapping.input.InputMap;
import com.amazon.device.inputmapping.input.InputMappingProvider;
import com.amazon.device.inputmapping.input.MouseSettings;

import java.util.Arrays;
import java.util.Collections;

public class MyInputMapProvider implements InputMappingProvider {

    public enum InputEventIds {
        MOVE,
        FAST_MOVE,
        PAUSE
    }

    @Override
    public InputMap onProvideInputMap() {
        InputAction moveLeft = InputAction.create(
                "Move left",
                InputEventIds.MOVE.ordinal(),
                InputControls.create(
                        Collections.singletonList(KeyEvent.KEYCODE_DPAD_LEFT),
                        Collections.emptyList()
                )
        );

        InputAction moveRight = InputAction.create(
                "Move right",
                InputEventIds.MOVE.ordinal(),
                InputControls.create(
                        Collections.singletonList(KeyEvent.KEYCODE_DPAD_RIGHT),
                        Collections.emptyList()
                )
        );


        InputAction fastMoveLeft = InputAction.create(
                "Move fast left",
                InputEventIds.FAST_MOVE.ordinal(),
                InputControls.create(
                        Arrays.asList(KeyEvent.KEYCODE_SHIFT_LEFT, KeyEvent.KEYCODE_DPAD_LEFT),
                        Collections.emptyList()
                )
        );

        InputAction fastMoveRight = InputAction.create(
                "Move fast right",
                InputEventIds.FAST_MOVE.ordinal(),
                InputControls.create(
                        Arrays.asList(KeyEvent.KEYCODE_SHIFT_LEFT, KeyEvent.KEYCODE_DPAD_RIGHT),
                        Collections.emptyList()
                )
        );

        InputAction pause = InputAction.create(
                "Pause/resume game",
                InputEventIds.FAST_MOVE.ordinal(),
                InputControls.create(
                        Collections.singletonList(KeyEvent.KEYCODE_P),
                        Collections.emptyList()
                )
        );

        InputGroup move = InputGroup.create("Move",
                Arrays.asList(moveLeft, moveRight));

        InputGroup moveFast = InputGroup.create("Move fast",
                Arrays.asList(fastMoveLeft, fastMoveRight));

        InputGroup pauseGroup = InputGroup.create("Pause",
                Collections.singletonList(pause));


        InputMap inputMap = InputMap.create(Arrays.asList(move, moveFast, pauseGroup),
                MouseSettings.create(true, true));

        return inputMap;
    }
}
